===============================
Otter
===============================

.. image:: https://img.shields.io/pypi/v/otter-report.svg
        :target: https://pypi.python.org/pypi/otter-report

.. image:: https://img.shields.io/travis/transientlunatic/otter.svg
        :target: https://travis-ci.org/transientlunatic/otter

.. image:: https://readthedocs.org/projects/otter/badge/?version=latest
        :target: https://readthedocs.org/projects/otter/?badge=latest
        :alt: Documentation Status


Otter is a simple HTML report generator for Python jobs. Otter was
designed to produce reports on long-running jobs on remote machines,
and send them to a web server.

* Free software: ISC license
* Documentation: https://otter.readthedocs.org.

Features
--------

* TODO Add support for pandas data tables
* TODO Add support for custom headers and footers

Credits
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-pypackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
